@@ -22,6 +22,7 @@ from openstack.compute.v2 import server_group as _server_group
 from openstack.compute.v2 import server_interface as _server_interface
 from openstack.compute.v2 import server_ip
 from openstack.compute.v2 import service as _service
+from openstack.compute.v2 import volume_attachment as _volume_attachment
 from openstack import proxy2
 from openstack import resource2
 
@@ -554,7 +555,7 @@ class Proxy(proxy2.BaseProxy):
         server.add_security_group(self._session, security_group_id)
 
     def remove_security_group_from_server(self, server, security_group):
-        """Add a security group to a server
+        """Remove a security group from a server
 
         :param server: Either the ID of a server or a
                        :class:`~openstack.compute.v2.server.Server` instance.
@@ -619,6 +620,22 @@ class Proxy(proxy2.BaseProxy):
         server = self._get_resource(_server.Server, server)
         server.remove_floating_ip(self._session, address)
 
+    def backup_server(self, server, name, backup_type, rotation):
+        """Backup a server
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param name: The name of the backup image.
+        :param backup_type: The type of the backup, for example, daily.
+        :param rotation: The rotation of the back up image, the oldest
+                         image will be removed when image count exceed
+                         the rotation count.
+
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.backup(self._session, name, backup_type, rotation)
+
     def pause_server(self, server):
         """Pauses a server and changes its status to ``PAUSED``.
 
@@ -774,6 +791,19 @@ class Proxy(proxy2.BaseProxy):
         server = self._get_resource(_server.Server, server)
         server.unshelve(self._session)
 
+    def get_server_console_output(self, server, length=None):
+        """Return the console output for a server.
+
+        :param server: Either the ID of a server or a
+                    :class:`~openstack.compute.v2.server.Server` instance.
+        :param length: Optional number of line to fetch from the end of console
+                    log. All lines will be returned if this is not specified.
+        :returns: The console output as a dict. Control characters will be
+                    escaped to create a valid JSON string.
+        """
+        server = self._get_resource(_server.Server, server)
+        return server.get_console_output(self._session, length=length)
+
     def wait_for_server(self, server, status='ACTIVE', failures=['ERROR'],
                         interval=2, wait=120):
         return resource2.wait_for_status(self._session, server, status,
@@ -1055,20 +1085,6 @@ class Proxy(proxy2.BaseProxy):
         """
         return self._get(_hypervisor.Hypervisor, hypervisor)
 
-    def get_service(self, service):
-        """Get a single service
-
-        :param service: The value can be the ID of a serivce or a
-               :class:`~openstack.compute.v2.service.Service`
-               instance.
-
-        :returns:
-            A :class:`~openstack.compute.v2.serivce.Service` object.
-        :raises: :class:`~openstack.exceptions.ResourceNotFound`
-                 when no resource can be found.
-        """
-        return self._get(_service.Service, service)
-
     def force_service_down(self, service, host, binary):
         """Force a service down
 
@@ -1120,3 +1136,149 @@ class Proxy(proxy2.BaseProxy):
         """
 
         return self._list(_service.Service, paginated=False)
+
+    def create_volume_attachment(self, server, **attrs):
+        """Create a new volume attachment from attributes
+
+        :param server: The server can be either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param dict attrs: Keyword arguments which will be used to create a
+            :class:`~openstack.compute.v2.volume_attachment.VolumeAttachment`,
+            comprised of the properties on the VolumeAttachment class.
+
+        :returns: The results of volume attachment creation
+        :rtype:
+            :class:`~openstack.compute.v2.volume_attachment.VolumeAttachment`
+        """
+        server_id = resource2.Resource._get_id(server)
+        return self._create(_volume_attachment.VolumeAttachment,
+                            server_id=server_id, **attrs)
+
+    def update_volume_attachment(self, volume_attachment, server,
+                                 **attrs):
+        """update a volume attachment
+
+        :param volume_attachment:
+            The value can be either the ID of a volume attachment or a
+            :class:`~openstack.compute.v2.volume_attachment.VolumeAttachment`
+            instance.
+        :param server: This parameter need to be specified when
+                       VolumeAttachment ID is given as value. It can be
+                       either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server`
+                       instance that the attachment belongs to.
+        :param bool ignore_missing: When set to ``False``
+                    :class:`~openstack.exceptions.ResourceNotFound` will be
+                    raised when the volume attachment does not exist.
+                    When set to ``True``, no exception will be set when
+                    attempting to delete a nonexistent volume  attachment.
+
+        :returns: ``None``
+        """
+        server_id = self._get_uri_attribute(volume_attachment, server,
+                                            "server_id")
+        volume_attachment = resource2.Resource._get_id(volume_attachment)
+
+        return self._update(_volume_attachment.VolumeAttachment,
+                            attachment_id=volume_attachment,
+                            server_id=server_id)
+
+    def delete_volume_attachment(self, volume_attachment, server,
+                                 ignore_missing=True):
+        """Delete a volume attachment
+
+        :param volume_attachment:
+            The value can be either the ID of a volume attachment or a
+            :class:`~openstack.compute.v2.volume_attachment.VolumeAttachment`
+            instance.
+        :param server: This parameter need to be specified when
+                       VolumeAttachment ID is given as value. It can be either
+                       the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server`
+                       instance that the attachment belongs to.
+        :param bool ignore_missing: When set to ``False``
+                    :class:`~openstack.exceptions.ResourceNotFound` will be
+                    raised when the volume attachment does not exist.
+                    When set to ``True``, no exception will be set when
+                    attempting to delete a nonexistent volume attachment.
+
+        :returns: ``None``
+        """
+        server_id = self._get_uri_attribute(volume_attachment, server,
+                                            "server_id")
+        volume_attachment = resource2.Resource._get_id(volume_attachment)
+
+        self._delete(_volume_attachment.VolumeAttachment,
+                     attachment_id=volume_attachment,
+                     server_id=server_id,
+                     ignore_missing=ignore_missing)
+
+    def get_volume_attachment(self, volume_attachment, server,
+                              ignore_missing=True):
+        """Get a single volume attachment
+
+        :param volume_attachment:
+            The value can be the ID of a volume attachment or a
+            :class:`~openstack.compute.v2.volume_attachment.VolumeAttachment`
+            instance.
+        :param server: This parameter need to be specified when
+                       VolumeAttachment ID is given as value. It can be either
+                       the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server`
+                       instance that the attachment belongs to.
+        :param bool ignore_missing: When set to ``False``
+                    :class:`~openstack.exceptions.ResourceNotFound` will be
+                    raised when the volume attachment does not exist.
+                    When set to ``True``, no exception will be set when
+                    attempting to delete a nonexistent volume attachment.
+
+        :returns: One
+            :class:`~openstack.compute.v2.volume_attachment.VolumeAttachment`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+                 when no resource can be found.
+        """
+        server_id = self._get_uri_attribute(volume_attachment, server,
+                                            "server_id")
+        volume_attachment = resource2.Resource._get_id(volume_attachment)
+
+        return self._get(_volume_attachment.VolumeAttachment,
+                         server_id=server_id,
+                         attachment_id=volume_attachment,
+                         ignore_missing=ignore_missing)
+
+    def volume_attachments(self, server):
+        """Return a generator of volume attachments
+
+        :param server: The server can be either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server`.
+
+        :returns: A generator of VolumeAttachment objects
+        :rtype:
+            :class:`~openstack.compute.v2.volume_attachment.VolumeAttachment`
+        """
+        server_id = resource2.Resource._get_id(server)
+        return self._list(_volume_attachment.VolumeAttachment, paginated=False,
+                          server_id=server_id)
+
+    def migrate_server(self, server):
+        """Migrate a server from one host to another
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.migrate(self._session)
+
+    def live_migrate_server(self, server, host=None, force=False):
+        """Migrate a server from one host to target host
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param host: The host to which to migrate the server
+        :param force: Force a live-migration by not verifying the provided
+                      destination host by the scheduler.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.live_migrate(self._session, host, force)
