@@ -12,7 +12,7 @@
 
 from openstack import format
 from openstack.identity import identity_service
-from openstack import resource
+from openstack import resource2 as resource
 
 
 class Role(resource.Resource):
@@ -23,16 +23,16 @@ class Role(resource.Resource):
 
     # capabilities
     allow_create = True
-    allow_retrieve = True
+    allow_get = True
     allow_update = True
     allow_delete = True
     allow_list = True
 
     # Properties
     #: The description of the role. *Type: string*
-    description = resource.prop('description')
-    #: Unique role name. *Type: string*
-    name = resource.prop('name')
+    description = resource.Body('description')
     #: Setting this attribute to ``False`` prevents this role from being
-    #: available in the role list.
-    enabled = resource.prop('enabled', type=format.BoolStr)
+    #: available in the role list. *Type: bool*
+    is_enabled = resource.Body('enabled', type=format.BoolStr)
+    #: Unique role name. *Type: string*
+    name = resource.Body('name')
